
package com.akwabasystems.exceptions;


/**
 * A class that handles generic user Interface (UI) exceptions
 */
public class UIException extends Exception {
    
    private String method;
    private String message;
    private String description;
    

    /**
     * Default constructor
     */
    public UIException() {
        super();
    }
    
    
    /**
     * Uses exception chaining by handling lower-level exceptions at higher level
     *
     * @param cause             the cause of the exception
     */
    public UIException(Throwable cause) {
        super(cause);
    }
    

    /**
     * Returns the description of the exception for debugging purposes
     *
     * @return the description of the exception for debugging purposes
     */
    public String getDescription() {
        return this.description;
    }

    
    /**
     * Displays a short description of the exception for debugging purposes
     *
     * @param method            the method that caused the exception
     * @param message           the description message to display for this exception
     */
    public UIException(String message, String description) {
        super(message);
        
        /** Save failure information for programmatic access */
        this.message = message;
        this.description = description;
    }
}
