
package com.akwabasystems.filters;


import java.io.StringWriter;
import javax.servlet.ServletOutputStream;


/**
 * StringOutputStream is a stub for ServletOutputStream that buffers out the 
 * output in a string buffer instead of sending it straight to the client
 */
public class StringOutputStream extends ServletOutputStream {
    
    
    private StringWriter stringWriter;
    
    
    /**
     * Default constructor
     */
    public StringOutputStream() {
        super();
    }


    /**
     * Overloaded constructor. Sets the reference to the {@code StringWriter} composition
     *
     * @param stringWriter              the {@code StringWriter} instance for this class
     */
    public StringOutputStream(StringWriter stringWriter) {
        this.stringWriter = stringWriter;
    }
    

    /**
     * Write the specified content to the output stream
     *
     * @param c             the content to write to the output stream
     */
    public void write(int c) {
        this.stringWriter.write(c);
    }

}
