
package com.akwabasystems.filters;


import java.io.PrintWriter;
import java.io.StringWriter;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletResponseWrapper;


/**
 * A response wrapper that takes everything the client would normally output
 * and saves it in one large string.
 */
public class StringWrapper extends HttpServletResponseWrapper {
    
    
    private StringWriter stringWriter;
    
    
    /**
     * Initializes wrapper.
     * First, this constructor calls the parent constructor so that the
     * response is stored and this setHeader, setStatus, addCookies, and so 
     * forth work normally.
     * 
     * Second, this constructor creates a StringWriter that will be used to
     * accummulate the response
     */
    public StringWrapper(HttpServletResponse response) {
        super(response);
        stringWriter = new StringWriter();
    }
    
    
    /**
     * When servlets or JSP pages ask for the Writer, do not give them the real
     * thing. Instead, give them a version that writes into the StringBuffer.
     * The filter needs to send the contents of the buffer to the client.
     */
    @Override 
    public PrintWriter getWriter() {
        return new PrintWriter(stringWriter);
    }
    
    
    /**
     * Similarly, when resources call getOutputStream, give them a phony one 
     * that just buffers the output
     */
    @Override
    public ServletOutputStream getOutputStream() {
        return new StringOutputStream(stringWriter);
    }
    
    
    /**
     * Get a string representation of the entire buffer.
     * Be sure not to call this method multiple times on the same
     * wrapper as the StringWriter API does not "remember" previous calls
     */
    @Override
    public String toString() {
        return stringWriter.toString();
    }
    
    
    /**
     * Get the underlying StringBuffer.
     */
    public StringBuffer getBuffer() {
        return stringWriter.getBuffer();
    }
}
