/**---------------------------------------------------------------------------------------------------------------------
                                         CONCIERGE API

     A module that provides a unified and easy-to-use API for the different use cases of the application
----------------------------------------------------------------------------------------------------------------------*/
Concierge.api = {
    
    modules : { },
    RESTEndpoint : "/WorkshopUI",
    Method : {
        GET : "GET",
        POST : "POST"
    },

    
    /**
     * Handles generic Ajax request exceptions
     * 
     * @param transport             the Ajax object used to send the request
     */
    handleError : function(transport) {
        Concierge.log("API Exception: %s", Object.evalJSON(transport.responseText));
    },


    /**
     * Adds the specified module to this "Concierge.api" namespace
     * 
     * @param name              the name of the module to add
     * @param module            the module to add
     */
    addModule : function(name, module) {
        this[name] = module;
        return this;
    },
    
    
    /**
     * Evaluates the URI pattern specified and generates the corresponding service URL (context path and evaluated
     * URI pattern) from it.
     *
     * @param pattern                   the URI pattern to evaluate
     * @param replacement               the replacement object that contains the properties to evaluate the 
     *                                  pattern with
     */
    getServiceURL : function(pattern, replacement) {
        var URLString = (replacement)? String.format(pattern, replacement) : pattern;
        return [this.RESTEndpoint, URLString].join("");
    }

};


/*----------------------------------------------------------------------------------------------------------------------
                                    EVENTS API

  A set of API methods for managing the retrieval and persistence of events
----------------------------------------------------------------------------------------------------------------------*/
(function() {
    "use strict";
    
    var uriPatterns = {
        TYPES : "/unit-test/ajax.txt",  //workshopTypes",
        TYPE_BY_ID : "/workshopTypes/{id}"
    };
    
    var workshopTypesApi = {

        /**
         * Retrieves the workshop events
         *
         * @param username              the account username
         * @param options               an object that contains the request options (
         */
        getAll : function(options) {
            var serviceURL = Concierge.api.getServiceURL(uriPatterns.TYPES, { }),
            method = Concierge.api.Method.GET;
            
            var ajax = new Concierge.Ajax();
            ajax.request(method, serviceURL, {
                parameters : {
                    timestamp : +new Date()
                },
                success : options.success,
                failure : options.failure
            });
        }
        
    };

    Concierge.api.addModule("workshopTypes", workshopTypesApi);

})();
