/**---------------------------------------------------------------------------------------------------------------------
                                   WORKSHOP FILTER

A module that manages the recent activities happening in a specific department

----------------------------------------------------------------------------------------------------------------------*/


Concierge.UI.WorkshopCalendar = Concierge.Class.create(Concierge.WidgetBase, {


    /**
     * Initializes the recent activity widget with the options specified
     *
     * @param options               the activity widget configuration options
     */
    initialize : function(options) {
        this.init(options);
        this.element = $("#" + this.options.element);
        $C.log("element: %s", this.element);
        
        this.handlers = {
        };
        
        var initialMode = options.initialMode;
        $C.log("Mode: %s", initialMode);
        
        this.currentMode = (initialMode && (!!this.options.viewMode[initialMode.toUpperCase()]))? 
            this.options.viewMode[initialMode.toUpperCase()] : this.options.viewMode.MONTH;
        $C.log("Current mode: %s", this.currentMode);
        
        this.render().registerEvents();
    },

    
    /**
     * Renders the view of this workshop calendar widget
     */
    render : function() {
       $C.log("Rendering calendar...");
       this.sectionContainer = $("#container");
       this.sectionSlider = $("#sectionSlider");
       this.calendarNavigation = $("#calendarNavigation");
       
       this.initializeCalendar();
       return this;
    },
    
    initializeCalendar : function() {
        this.calendarViewContainerMonth = $("#calendarViewMonth");
        this.calendarViewContainerList = $("#calendarViewList");
        
        this.calendar = new Concierge.UI.Calendar({
            delegate : this
        });
        
        this.calendar.renderInView(this.calendarViewContainerMonth[0], Concierge.UI.Calendar.type.TABLE);
        $C.log("Initialized calendar - isMonthView Mode: %s", this.isMonthViewMode());
    },
    
    
    registerEvents : function() {
        this.sectionSlider.click(this.toggleSidebar.bind(this));
        this.calendarNavigation.click(this.onCalendarNavigation.bind(this));
        
        this.subscribe(Concierge.CoreEvents.FILTER_SELECTED, this.onFilterSelected.bind(this));
        return this;
    },
    
    isMonthViewMode : function() {
        return (this.currentMode == this.options.viewMode.MONTH);
    },
    
    
    isListViewMode : function() {
        return (this.currentMode == this.options.viewMode.LIST);
    },
    
    
    toggleSidebar : function(event) {
        event.preventDefault();
        var source = $(event.target), hideSidebar = source.hasClass("hide");
        
        if(hideSidebar) {
            source.html("Show").attr({ "class" : "show", title : "Show panel" });
            this.sectionContainer.addClass("stretched");
        } else {
            source.html("Hide").attr({ "class" : "hide", title : "Hide panel" });
            this.sectionContainer.removeClass("stretched");
        }
    },
    
    onCalendarNavigation : function(event) {
        event.preventDefault();
        var source = $(event.target);
        
        if(source.is("a")) {
            $C.log("Navigating to day: %s", source.attr("rel"));
        }
    },
    
    
    onFilterSelected : function(event) {
        var filter = event.model;
        $C.log(">> Calendar: received filter event - current category: %s", filter.id);
    }
    

});


Object.extend(Concierge.UI.WorkshopCalendar, {
    defaultOptions : {
        element : "calendarViews",
        viewMode : {
            MONTH : "month",
            LIST : "list"
        },
        templates : {
        }
    },

    getInstance : Concierge.UI.WorkshopCalendar

});
