/**---------------------------------------------------------------------------------------------------------------------
                                   WORKSHOP FILTER

A module that manages the recent activities happening in a specific department

----------------------------------------------------------------------------------------------------------------------*/


Concierge.UI.WorkshopFilter = Concierge.Class.create(Concierge.WidgetBase, {


    /**
     * Initializes the recent activity widget with the options specified
     *
     * @param options               the activity widget configuration options
     */
    initialize : function(options) {
        this.init(options);
        this.element = $("#" + this.options.element);
        $C.log("element: %s", this.element);
        
        this.handlers = {
        };

        this.render.bind(this).delay(this.options.delay);
        
    },

    
    /**
     * Renders the view of this workshop filter widget
     */
    render : function() {
        this.itemContainer = $("<ul></ul>").attr({ id : "filters", "class" : "filters" });
        this.itemContainer.appendTo(this.element);
        $C.log("Rendered view...");
        
        return this.retrieveWorkshopCategories();
    },
    
    
    retrieveWorkshopCategories : function() {
        // Temporary implementations
        this.categories = [
            { id : "workshops", title : "Workshops" },
            { id : "one-to-one", title : "One to One" },
            { id : "venture", title : "Joint Venture" },
            { id : "labs", title : "Pro Labs" },
            { id : "youth", title : "Youth" },
            { id : "special-events", title : "Special Events" }
        ];
        
        this.onCategoriesAvailable();
        return this;
    },
    
    
    /**
     * This method gets invoked when the recent activities are retrieved. It renders the activity view as a list view
     *
     * @param transport             the Ajax request object used to retrieve the recent activities
     */
    onCategoriesAvailable : function(transport) {
        this.categoryView = new Concierge.UI.ListView({
            id : "itemFilters",
            element : this.element,
            itemContainer : this.itemContainer,
            delegate : this,
            emptyContentMessage : "No categories available"
        });
    },

    
    /**
     * Returns the data source to use to populate the ListView widget instance. This is a delegate method
     * for the {@code Concierge.UI.ListView} widget
     *
     * @return the data source to use to populate the {@Concierge.UI.ListView} widget instance
     */
    getDataSource : function() {
        return this.categories;
    },


    /**
     * Returns the template to use to generate the view of the ListView widget instance. This is a delegate
     * method for the {@code Concierge.UI.ListView} widget
     *
     * @return the template to use to generate the view for the ListView widget instance
     */
    getTemplate : function() {
        return this.options.templates.FILTER;
    },


    /**
     * Gets invoked after the view of the recent activity list is rendered. This is a required delegate method of
     * the ListView widget, and this implementation is empty
     *
     * @param container                 the container node of the ListView instance element
     */
    afterViewRendered : Function.empty,


    /**
     * Gets invoked after an item is added to the ListView widget. This delegate method is currently empty
     */
    afterItemAdded : Function.empty,


    /**
     * Gets invoked when an activity item is selected. This is a delegate method for the {@code Concierge.UI.ListView}
     * widget
     */
    onItemClicked : function(event) {
        event.preventDefault();
        var source = $(event.target);

        if(source) {
            var currentCategory = this.findCategoryByID(source.attr("rel"));
            $C.log("Selected category: %s", (currentCategory)? currentCategory.title : "");
            
            this.publish(Concierge.CoreEvents.FILTER_SELECTED, currentCategory);
        }
    },
    
    
    findCategoryByID : function(id) {
        return this.categories.find(function(category) {
           return (category.id == id); 
        });
    }

});


Object.extend(Concierge.UI.WorkshopFilter, {
    defaultOptions : {
        element : "filters",
        templates : {
            FILTER : '<a href="#" class="{id}" rel="{id}">{title}</a>'
        }
    },

    getInstance : Concierge.UI.WorkshopFilter

});
